@@ -1,3 +1,4 @@
+from regex import E
 from dt.ext.aws_s3 import get_lastest_file
 from cement import Controller, ex
 from cement.utils.version import get_version_banner
@@ -284,11 +285,14 @@ class Base(Controller):
         ]
     )
     def cai(self):
-        from ..ext.codex import get_cai_suggestions
+        from ..ext.codex import get_cai_suggestions, list_models
         import pprint as pp
 
-        suggestions = get_cai_suggestions(self.app.pargs.text, self.app.pargs.n_suggestions)
-        pp.pprint(suggestions)
+        if self.app.pargs.text=='ls':
+            pp.pprint(list_models())
+        else:
+            suggestions = get_cai_suggestions(self.app.pargs.text, self.app.pargs.n_suggestions)
+            pp.pprint(suggestions)
 
 
     @ex(
