@@ -10,8 +10,8 @@ def load_api_key(api_key_file):
 
 # construct a function that calls the openai codex and returns the results
 def constuct_call(api_key, prompt):
-    engine = 'cushman-codex' # codex engine could also be
     # engine = 'davinci-codex'
+    engine = "text-davinci-002"
     url = f'https://api.openai.com/v1/engines/{engine}/completions'
     data = { 'prompt': prompt, 'max_tokens' : 200  } # 'stream': True
 
@@ -27,7 +27,7 @@ def get_cai_suggestions(query: str, n_suggestions: int = 5):
     # measure timing 
     start = time.time()
     # get the api key from the home directory 
-    api_path = os.path.join(os.path.expanduser('~'), 'dt_config.json')
+    api_path = os.path.join(os.path.expanduser('~'), ".dt_config.json")
     api_key = load_api_key(api_path)
     response = constuct_call(api_key, query)
     after = time.time()
@@ -40,3 +40,15 @@ def get_cai_suggestions(query: str, n_suggestions: int = 5):
 
     return response_dict
 
+
+def list_models():
+    # curl https://api.openai.com/v1/models \
+    #   -H 'Authorization: Bearer YOUR_API_KEY'
+    api_path = os.path.join(os.path.expanduser('~'), ".dt_config.json")
+    api_key = load_api_key(api_path)
+    url = 'https://api.openai.com/v1/models'
+    headers = {'Authorization': 'Bearer {}'.format(api_key),
+                'Content-Type': 'application/json'}
+    response = requests.get(url, headers=headers)
+    response_dict = json.loads(response.text)
+    return response_dict
\ No newline at end of file
